<?php

/**
 * This is the model class for table "tbl_cliente_pesquisa".
 *
 * The followings are the available columns in table 'tbl_cliente_pesquisa':
 * @property string $id_cliente
 * @property string $nome_cliente
 * @property string $sobrenome_cliente
 * @property string $dtnasc_cliente
 * @property string $cpf_cliente
 * @property string $sexo_cliente
 * @property string $email_cliente
 * @property string $ddd_tel_cliente
 * @property string $tel_cliente
 * @property string $ddd_cel_cliente
 * @property string $cel_cliente
 * @property string $ddd_tel_comercial_cliente
 * @property string $tel_comercial_cliente
 * @property string $tipo_endereco_cliente
 * @property string $cep_cliente
 * @property string $endereco_cliente
 * @property string $bairro_cliente
 * @property string $numero_cliente
 * @property string $complemento_cliente
 * @property string $pais_cliente
 * @property string $estado_cliente
 * @property string $receber_informacoes_cliente
 * @property string $cidade_cliente
 *
 * The followings are the available model relations:
 * @property TblPesquisa[] $tblPesquisas
 */
class ClientePesquisa extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return ClientePesquisa the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return 'tbl_cliente_pesquisa';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('nome_cliente, sobrenome_cliente, dtnasc_cliente, cpf_cliente, sexo_cliente, email_cliente, ddd_tel_cliente, tel_cliente, ddd_cel_cliente, cel_cliente, tipo_endereco_cliente, cep_cliente, endereco_cliente, bairro_cliente, pais_cliente, estado_cliente,receber_informacoes_cliente', 'required'),
			array('nome_cliente, sobrenome_cliente, pais_cliente,cidade_cliente', 'length', 'max'=>100),
			array('dtnasc_cliente, cep_cliente, numero_cliente ', 'length', 'max'=>10),
			array('cpf_cliente', 'length', 'max'=>14),
			array('sexo_cliente, tipo_endereco_cliente', 'length', 'max'=>1),
			array('email_cliente, endereco_cliente, bairro_cliente, complemento_cliente', 'length', 'max'=>200),
			array('ddd_tel_cliente, ddd_cel_cliente, ddd_tel_comercial_cliente', 'length', 'max'=>2),
			array('tel_cliente, cel_cliente, tel_comercial_cliente', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id_cliente, nome_cliente, sobrenome_cliente, dtnasc_cliente, cpf_cliente, sexo_cliente, email_cliente, ddd_tel_cliente, tel_cliente, ddd_cel_cliente, cel_cliente, ddd_tel_comercial_cliente, tel_comercial_cliente, tipo_endereco_cliente, cep_cliente, endereco_cliente, bairro_cliente, numero_cliente, complemento_cliente, pais_cliente, estado_cliente, receber_informacoes_cliente, cidade_cliente', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
		// NOTE: you may need to adjust the relation name and the related
		// class name for the relations automatically generated below.
		return array(
			'tblPesquisas' => array(self::HAS_MANY, 'TblPesquisa', 'id_cliente_pesquisa'),
		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id_cliente' => 'Id Cliente',
			'nome_cliente' => 'Seu Nome',
			'sobrenome_cliente' => 'Sobrenome',
			'dtnasc_cliente' => 'Data de Nascimento',
			'cpf_cliente' => 'CPF',
			'sexo_cliente' => 'Sexo',
			'email_cliente' => 'E-mail',
			'ddd_tel_cliente' => 'DDD',
			'tel_cliente' => 'Telefone Residencial',
			'ddd_cel_cliente' => 'DDD',
			'cel_cliente' => 'Celular',
			'ddd_tel_comercial_cliente' => 'DDD',
			'tel_comercial_cliente' => 'Telefone Comercial',
			'tipo_endereco_cliente' => 'Tipo de Endereço',
			'cep_cliente' => 'Cep',
			'endereco_cliente' => 'Endereço',
			'bairro_cliente' => 'Bairro',
			'numero_cliente' => 'Número',
			'complemento_cliente' => 'Complemento',
			'pais_cliente' => 'País',
			'estado_cliente' => 'Estado',
			'receber_informacoes_cliente' => 'Aceito receber informações sobre Vichy:',
			'cidade_cliente' => 'Cidade',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id_cliente',$this->id_cliente,true);
		$criteria->compare('nome_cliente',$this->nome_cliente,true);
		$criteria->compare('sobrenome_cliente',$this->sobrenome_cliente,true);
		$criteria->compare('dtnasc_cliente',$this->dtnasc_cliente,true);
		$criteria->compare('cpf_cliente',$this->cpf_cliente,true);
		$criteria->compare('sexo_cliente',$this->sexo_cliente,true);
		$criteria->compare('email_cliente',$this->email_cliente,true);
		$criteria->compare('ddd_tel_cliente',$this->ddd_tel_cliente,true);
		$criteria->compare('tel_cliente',$this->tel_cliente,true);
		$criteria->compare('ddd_cel_cliente',$this->ddd_cel_cliente,true);
		$criteria->compare('cel_cliente',$this->cel_cliente,true);
		$criteria->compare('ddd_tel_comercial_cliente',$this->ddd_tel_comercial_cliente,true);
		$criteria->compare('tel_comercial_cliente',$this->tel_comercial_cliente,true);
		$criteria->compare('tipo_endereco_cliente',$this->tipo_endereco_cliente,true);
		$criteria->compare('cep_cliente',$this->cep_cliente,true);
		$criteria->compare('endereco_cliente',$this->endereco_cliente,true);
		$criteria->compare('bairro_cliente',$this->bairro_cliente,true);
		$criteria->compare('numero_cliente',$this->numero_cliente,true);
		$criteria->compare('complemento_cliente',$this->complemento_cliente,true);
		$criteria->compare('pais_cliente',$this->pais_cliente,true);
		$criteria->compare('estado_cliente',$this->estado_cliente,true);
		$criteria->compare('receber_informacoes_cliente',$this->receber_informacoes_cliente,true);
		$criteria->compare('cidade_cliente',$this->cidade_cliente,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}